@@ -60,6 +60,25 @@ def del_corr_mask(array, corr_criterion=0.99):
     
     return mask
 
+def del_corr_mask_old(array, corr_criterion=0.95):
+    """
+    """
+    mask = np.array(range(1, array.shape[1]+1), dtype=bool)
+    corr_matrix = np.abs(np.tril(np.corrcoef(array.T), k=-1))
+    
+    while corr_matrix.max() >= corr_criterion:
+        # print(corr_matrix.max())
+        tuple_location = np.unravel_index(corr_matrix.argmax(), corr_matrix.shape)
+        # print(tuple_location)
+        corr_matrix[tuple_location] = 0
+        if mask[min(tuple_location)]:
+            if mask[max(tuple_location)]:
+                mask[max(tuple_location)] = False
+        # mask[max(tuple_location)] = False
+        
+        
+    return mask
+
 if __name__ == "__main__":
     
     from sklearn.datasets import make_regression
