@@ -1,3 +1,3 @@
 
 from .check import check_is_1D, check_not_2D, check_2D
-from .common import linspace
\ No newline at end of file
+from .common import linspace, split_array, split_range
\ No newline at end of file
